# complyadm

A set of Bolt plans for installing and managing Puppet Comply.

## Installation Instructions

Initial steps to get up and running. Common approach for all devs.

Prerequisites:

- Ruby 2.7
- [vmfloaty](https://rubygems.org/gems/vmfloaty)

Instructions:

1. Install Ruby dependencies by running `bundle install`
2. Install Bolt dependencies by running `bundle exec bolt module install`
3. Grab a VM by running `floaty get ubuntu-2004-x86_64-pooled` (for example)
4. Create an `inventory.yaml` file with connection information for the host on which Comply will be installed. For
   example:

```
---
targets:
- uri: <enter vm hostname that was created above>
  name: comply-host
  config:
    transport: ssh
    ssh:
       host-key-check: false
       user: root
```

5. Install Comply on the target host by running `bundle exec bolt plan run complyadm::install [upload_images=<value>] [ignore_failing_preflights=<value>]`

## Uninstall Instructions

With the same `images.yaml` used to install.

1. Uninstall Comply on the target host by running `bundle exec bolt plan run complyadm::uninstall`

**Additional Info**

User can generate mTLS proxy certs by including their PE in in the inventory file and by selecting the generate certs option during install. For example:

```
---
targets:
- uri: <enter vm hostname that was created above>
  name: comply-host
  config:
    transport: ssh
    ssh:
       host-key-check: false
       user: root
- uri: pe.delivery.puppetlabs.net
  name: pe-host
  config:
     transport: ssh
     ssh:
       host-key-check: false
       user: root
```

User can migrate from an existing 2.X Replicated install by including their Replicated host in the inventory file and running the migrate task. For example:

```
---
targets:
- uri: <enter vm hostname that was created above>
  name: comply-host
  config:
    transport: ssh
    ssh:
       host-key-check: false
       user: root
- uri: comply.delivery.puppetlabs.net
  name: replicated-comply-host
  config:
     transport: ssh
     ssh:
       host-key-check: false
       user: root
```

`bundle exec bolt plan run complyadm::migrate`

PE node can also be included in the above inventory aswell.

**Feature Flags**

Feature flags may be added to `data/dev.yaml`. For example:

```
---
complyadm::dev:
  features: ["nolicense", "insecure"]
```

- `nolicense` - disable license check
- `cem_up_sell` - adds a banner to the dashboard
- `insecure` - allows insecure communication with PE (no mTLS certificates are necessary)

**Images**

Comply's stable/release images are used by default. To use `master` images add the following to `data/dev.yaml`:

```
---
complyadm::dev:
  version: master
```

When using `master` images you must pass `upload_images=false` to the install/migrate/upgrade plans because `master` images are not in the GCS bucket
