# @summary installs and configures the frontdoor component.
#
# @param config subset of Complyadm::Config specific to the frontdoor service.
class complyadm::component::frontdoor (
  Complyadm::Config::Comply_frontdoor $config
) {
  include complyadm::log_rotation

  $container = $config['container']

  $conf_file = '/etc/puppetlabs/comply/frontdoor_proxy_nginx.conf'
  file { $conf_file:
    ensure  => 'file',
    content => epp('complyadm/frontdoor/nginx_conf.epp', { runtime => $container['runtime'] }),
    owner   => 'root',
    group   => 'root',
    seltype => 'container_file_t',
    notify  => Complyadm::Runtime::Run[$container['name']],
  }

  $healthcheck_file = "/etc/puppetlabs/comply/${container['name']}-healthcheck.sh"
  file { $healthcheck_file:
    ensure    => file,
    owner     => 'root',
    group     => 'root',
    mode      => '+x',
    seltype   => 'container_file_t',
    show_diff => false,
    content   => epp('complyadm/runtime/service-watchdog.epp', { healthcheck => "${container['runtime']} exec ${container['name']} ${container['healthcheck']}" }),
    notify    => Complyadm::Runtime::Run[$container['name']],
  }

  $cert_chain = '/etc/puppetlabs/comply/comply_certs/cert_chain.pem'
  file { $cert_chain:
    ensure  => 'file',
    content => $config['cert_chain'],
    owner   => 'root',
    group   => 'root',
    seltype => 'container_file_t',
    notify  => Complyadm::Runtime::Run[$container['name']],
  }

  $private_key = '/etc/puppetlabs/comply/comply_certs/private_key.pem'
  file { $private_key:
    ensure  => 'file',
    content => $config['private_key'],
    owner   => 'root',
    group   => 'root',
    seltype => 'container_file_t',
    notify  => Complyadm::Runtime::Run[$container['name']],
  }

  $crl = '/etc/puppetlabs/comply/comply_certs/crl.pem'
  file { $crl:
    ensure  => 'file',
    content => $config['crl'],
    owner   => 'root',
    group   => 'root',
    seltype => 'container_file_t',
    notify  => Complyadm::Runtime::Run[$container['name']],
  }

  complyadm::runtime::run { $container['name']:
    runtime          => $container['runtime'],
    install_runtime  => $container['install_runtime'],
    image            => $container['image'],
    net              => $container['net'],
    extra_parameters => $container['extra_parameters'],
    ports            => $container['ports'],
    pull_on_start    => false,
    volumes          => [
      "${conf_file}:/opt/bitnami/nginx/conf/nginx.conf",
      '/etc/puppetlabs/comply/comply_certs:/certs',
      '/etc/puppetlabs/comply/nginx_healthcheck.sh:/health/nginx_healthcheck.sh',
    ],
    after            => $container['after'],
  }
}
