# @summary installs and configures the main backend component
#
# @param config subset of Complyadm::Config specific to redis
class complyadm::component::redis (
  Complyadm::Config::Comply_redis $config,
) {
  $container = $config['container']

  complyadm::runtime::volume { 'redis':
    ensure  => 'present',
    runtime => $container['runtime'],
  }

  $redis_env = '/etc/puppetlabs/comply/redis.env'
  file { $redis_env:
    ensure    => file,
    owner     => 'root',
    group     => 'root',
    seltype   => 'container_file_t',
    show_diff => false,
    content   => epp('complyadm/comply_env.epp', {
        env_vars => $container['env_vars'],
    }),
    notify    => Complyadm::Runtime::Run[$container['name']],
  }

  $healthcheck_file = "/etc/puppetlabs/comply/${container['name']}-healthcheck.sh"
  file { $healthcheck_file:
    ensure    => file,
    owner     => 'root',
    group     => 'root',
    mode      => '+x',
    seltype   => 'container_file_t',
    show_diff => false,
    content   => epp('complyadm/runtime/service-watchdog.epp', { healthcheck => "${container['runtime']} exec ${container['name']} ${container['healthcheck']}" }),
    notify    => Complyadm::Runtime::Run[$container['name']],
  }

  complyadm::runtime::run { $container['name']:
    runtime                  => $container['runtime'],
    install_runtime          => $container['install_runtime'],
    image                    => $container['image'],
    net                      => $container['net'],
    extra_parameters         => $container['extra_parameters'],
    after_create             => $healthcheck_file,
    extra_systemd_parameters => $container['extra_systemd_parameters'],
    ports                    => $container['ports'],
    pull_on_start            => false,
    cmd                      => $container['cmd'],
    volumes                  => ['redis:/data'],
    env_file                 => [$redis_env],
    require                  => [
      Complyadm::Runtime::Volume['redis'],
      File[$redis_env],
      File[$healthcheck_file],
    ],
  }
}
