# @summary installs and configures the main backend component
#
# @param config subset of Complyadm::Config specific to scarpy
class complyadm::component::scarpy (
  Complyadm::Config::Comply_scarpy $config,
) {
  $container = $config['container']

  $scarpy_env = '/etc/puppetlabs/comply/scarpy.env'
  file { $scarpy_env:
    ensure    => file,
    owner     => 'root',
    group     => 'root',
    seltype   => 'container_file_t',
    show_diff => false,
    content   => epp('complyadm/comply_env.epp', { env_vars => $container['env_vars'] }),
    notify    => Complyadm::Runtime::Run[$container['name']],
  }

  # copy of file is maintained so that scarpy restarted if ca crt updated
  $ca_cert_scarpy = '/etc/puppetlabs/comply/pe_certs/.ca.crt.scarpy'
  file { $ca_cert_scarpy:
    ensure  => file,
    content => $config['ca_crt'],
    notify  => Complyadm::Runtime::Run[$container['name']],
  }

  complyadm::runtime::run { $container['name']:
    runtime          => $container['runtime'],
    install_runtime  => $container['install_runtime'],
    image            => $container['image'],
    net              => $container['net'],
    extra_parameters => $container['extra_parameters'],
    ports            => $container['ports'],
    pull_on_start    => false,
    env_file         => [$scarpy_env],
    require          => [File[$scarpy_env]],
    volumes          => [
      'benchmarks:/Assessor-CLI',
      '/etc/puppetlabs/comply/pe_certs:/certs',
    ],
    after            => $container['after'],
  }
}
