# @summary installs and configures the ui service component.
#
# @param config subset of Complyadm::Config specific to the ui service.
class complyadm::component::ui (
  Complyadm::Config::Comply_ui $config
) {
  include complyadm::log_rotation

  $container = $config['container']

  $ui_env = '/etc/puppetlabs/comply/ui.env'
  file { $ui_env:
    ensure    => file,
    owner     => 'root',
    group     => 'root',
    seltype   => 'container_file_t',
    show_diff => false,
    content   => epp('complyadm/comply_env.epp', { env_vars => $container['env_vars'] }),
    notify    => Complyadm::Runtime::Run[$container['name']],
  }

  complyadm::runtime::run { $container['name']:
    runtime          => $container['runtime'],
    install_runtime  => $container['install_runtime'],
    image            => $container['image'],
    net              => $container['net'],
    extra_parameters => $container['extra_parameters'],
    pull_on_start    => false,
    env_file         => [$ui_env],
    require          => File[$ui_env],
    volumes          => [
      'assessors:/usr/src/app/public/files',
    ],
    after            => $container['after'],
  }
}
