# @summary Base comply class that configures the system for anything shared across
# multiple components.
#
# @param runtime which runtime is being used
# @param ca_crt puppet ca cert
class complyadm (
  Complyadm::Runtime $runtime,
  Optional[String] $ca_crt = undef,
) {
  file { '/etc/puppetlabs/comply':
    ensure => directory,
    owner  => 'root',
    group  => 'root',
    mode   => '0700',
  }

  file { '/etc/puppetlabs/comply/pe_certs':
    ensure  => directory,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => File['/etc/puppetlabs/comply'],
  }

  file { '/etc/puppetlabs/comply/comply_certs':
    ensure  => directory,
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => File['/etc/puppetlabs/comply'],
  }

  $ca_cert = '/etc/puppetlabs/comply/pe_certs/ca.crt'
  file { $ca_cert:
    ensure  => 'file',
    content => $ca_crt,
    owner   => 'root',
    group   => 'root',
  }

  file { '/etc/puppetlabs/comply/nginx_healthcheck.sh':
    ensure  => file,
    source  => 'puppet:///modules/complyadm/healthchecks/bitnami-nginx-healthcheck.sh',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => File['/etc/puppetlabs/comply'],
  }

  if($runtime == 'docker') {
    docker_network { 'comply':
      ensure  => present,
    }
  } elsif($runtime == 'podman') {
    exec { 'podman network create comply':
      path   => '/usr/bin',
      unless => 'podman network inspect comply',
    }
  }
}
