# Creates a volume for the given name using the configured
# runtime (docker or podman).  Docker leverages the docker
# module's `docker_volume` resource, while podman uses an
# `exec` resource to directly create the volume
#
# @param ensure [Enum] The desired state of the volume
# @param runtime [String] The runtime to use for creating the volume
define complyadm::runtime::volume (
  Enum['present','absent'] $ensure = 'present',
  Complyadm::Runtime $runtime = 'docker',
) {
  if($runtime == 'docker') {
    docker_volume { $name:
      ensure => $ensure,
    }
  } elsif($runtime == 'podman') {
    if($ensure == 'present') {
      exec { "podman volume create ${name}": #lint:ignore:check_unsafe_interpolations
        path   => '/usr/bin',
        unless => "podman volume inspect ${name}",
      }
    } else {
      exec { "podman volume rm ${name}": #lint:ignore:check_unsafe_interpolations
        path   => '/usr/bin',
        onlyif => "podman volume inspect ${name}", #lint:ignore:check_unsafe_interpolations
      }
    }
  } else {
    fail("Unsupported runtime in volume create: ${runtime}")
  }
}
