# @api private
#
# @summary Install Comply based on an existing hiera config.
#
# @param [Optional[Boolean]] ignore_failing_preflights Setting to true will ignore failed preflight checks.
# @param [Optional[Boolean]] upload_images Setting to true will curl images locally from a public GCS bucket and then upload to the install target. Setting to false will pull images directly from the registry on the install target.
plan complyadm::install_from_config(
  Optional[Boolean] $ignore_failing_preflights = false,
  Optional[Boolean] $upload_images = true
) {
  $config = complyadm::config()

  run_plan('complyadm::preflight',
    config => $config,
    ignore_failing_preflights => $ignore_failing_preflights,
  )

  if $config['install_runtime'] {
    run_plan('complyadm::install::runtime',
      config => $config,
    )
  }

  if $upload_images {
    run_plan('complyadm::install::upload_images',
      config => $config,
    )
  } else {
    run_plan('complyadm::install::download_images',
      config => $config,
    )
  }

  run_command('mkdir -p /etc/puppetlabs',
    $config['all_targets'],
    { '_run_as' => 'root', '_catch_errors' => true }
  )

  run_plan('complyadm::install::roles',
    config => $config,
  )

  run_plan('complyadm::install::wait_for_services',
    config => $config,
  )

  run_plan('complyadm::install::overview',
    config => $config
  )
}
