# This plan takes a Comply config, redacts all sensitive data, and writes it to
# a file in the support bundle on localhost.
#
# @api private
# @param config The Comply config
# @param support_bundle_dir The absolute path to the support bundle directory
plan complyadm::support_bundle::config(
  Complyadm::Config $config,
  String[1] $support_bundle_dir,
) {
  # redact the values of sensitive environment variables
  $redacted_message = '[*** REDACTED ***]'
  $redacted_config = deep_merge($config,
    {
      'roles' => {
        'backend' => {
          'services' => {
            'comply_assessor_upgrade' => {
              'container' => {
                'env_vars' => {
                  'DB_PASSWORD' => $redacted_message,
                  'DB_ENCRYPTION_KEY' => $redacted_message,
                },
              },
            },
            'comply_gatekeeper' => {
              'client_secret' => $redacted_message,
              'cookie_secret' => $redacted_message,
            },
            'comply_graphql' => {
              'container' => {
                'env_vars' => {
                  'HASURA_GRAPHQL_ADMIN_SECRET' => $redacted_message,
                  'HASURA_GRAPHQL_DATABASE_URL' => $redacted_message,
                },
              },
            },
            'comply_graphql_init' => {
              'container' => {
                'env_vars' => {
                  'DB_PASSWORD' => $redacted_message,
                  'HASURA_ADMIN_SECRET' => $redacted_message,
                },
              },
            },
            'comply_identity' => {
              'client_secret' => $redacted_message,
              'container' => {
                'env_vars' => {
                  'COMPLY_DB_PASSWORD' => $redacted_message,
                  'KC_DB_PASSWORD' => $redacted_message,
                  'KEYCLOAK_ADMIN_PASSWORD' => $redacted_message,
                  'DB_ENCRYPTION_KEY' => $redacted_message,
                },
              },
            },
            'comply_scarpy' => {
              'container' => {
                'env_vars' => {
                  'DB_PASSWORD' => $redacted_message,
                  'HASURA_ADMIN_SECRET' => $redacted_message,
                  'DB_ENCRYPTION_KEY' => $redacted_message,
                },
              },
            },
            'comply_scarpy_init' => {
              'container' => {
                'env_vars' => {
                  'DB_PASSWORD' => $redacted_message,
                  'DB_ENCRYPTION_KEY' => $redacted_message,
                },
              },
            },
          },
        },
        'database' => {
          'services' => {
            'comply_postgres' => {
              'comply_db_password' => $redacted_message,
              'identity_db_password' => $redacted_message,
              'container' => {
                'env_vars' => {
                  'POSTGRES_PASSWORD' => $redacted_message,
                },
              },
            },
          },
        },
      }
    }
  )

  # write the redacted config to ${support_bundle_dir}/config/config.json
  $support_bundle_config_dir = file::join($support_bundle_dir, 'config')
  run_command("mkdir ${support_bundle_config_dir}", 'localhost')
  $config_file = file::join($support_bundle_config_dir, 'config.json')
  file::write($config_file, stdlib::to_json_pretty($redacted_config))
}
