# @summary Upgrade Security Compliance Management.
#
# Use this plan to upgrade an existing installation of Security Compliance Management. For complete instructions on how to use this plan
# to upgrade Security Compliance Management, see https://www.puppet.com/docs/comply/3.x/upgrade-comply-module.
#
# @param [Optional[Boolean]] ignore_failing_preflights Setting to true will ignore failed preflight checks.
# @param [Optional[Boolean]] upload_images Setting to true will curl images locally from a public GCS bucket and then upload to the install target. Setting to false will pull images directly from the registry on the install target.
plan complyadm::upgrade(
  Optional[Boolean] $ignore_failing_preflights = false,
  Optional[Boolean] $upload_images = true
) {
  run_plan('complyadm::check_bolt_version')

  $config = complyadm::config()

  run_plan('complyadm::preflight',
    config => $config,
    ignore_failing_preflights => $ignore_failing_preflights,
  )

  if $config['install_runtime'] {
    run_plan('complyadm::install::runtime',
      config => $config,
    )
  }

  if $upload_images {
    run_plan('complyadm::install::upload_images',
      config => $config,
    )
  } else {
    run_plan('complyadm::install::download_images',
      config => $config,
    )
  }

  run_plan('complyadm::install::roles',
    config => $config,
  )

  run_plan('complyadm::install::wait_for_services',
    config => $config,
  )

  run_plan('complyadm::upgrade::cleanup',
    config => $config,
  )
}
