# @summary Configuration values for Comply
#
# Values are populated from both user input via {Complyadm::Hiera_config}
# and hard-coded application defaults.
#
# This Datatype can be new-ed up using the function {Complyadm::Config()}
#
# @example running a command against all Comply infra targets
#   $config = Complyadm::Config()
#   $targets = $config['all_targets']
#   run_command($targets, 'whoami')
type Complyadm::Config = Struct[{
    all_targets                  => Array[Target],
    images                       => Struct[{
        comply_graphql              => String[1],
        comply_graphql_init         => String[1],
        comply_scarpy               => String[1],
        comply_scarpy_init          => String[1],
        comply_ui                   => String[1],
        comply_frontdoor            => String[1],
        comply_redis                => String[1],
        comply_mtls_proxy           => String[1],
        comply_scarpy_assessor_init => String[1],
        comply_ui_assessor_init     => String[1],
        comply_assessor_upgrade     => String[1],
        comply_identity             => String[1],
        comply_gatekeeper           => String[1],
        comply_postgres             => String[1],
    }],
    roles               => Complyadm::Roles,
    runtime             => Complyadm::Runtime,
    install_runtime     => Boolean,
    backup_dir          => String[1],
    dump_filename       => String[1],
    ssl => Optional[Struct[{
          cert_chain  => Optional[String[1]],
          crl         => Optional[String[1]],
          private_key => Variant[Sensitive[String[1]], Sensitive[Undef]],
    }]],
    resolvable_hostname => Optional[String[1]],
    assessor_version    => String[1],
    pe                  => String,
    ca_crt              => String,
    tls_crt             => String,
    tls_key             => String,
}]
